@@ -1,11 +1,16 @@
 import fastkml
+import logging
 import lxml
+import re
 import requests
 
 from seantis.placemap import _
 from seantis.plonetools import tools
 
 
+log = logging.getLogger('seantis.placemap')
+
+
 def translate_kml_document(request, document):
     # collective.geo.kml doesn't correctly translate strings in KML, so we
     # do it here to work around this issue.
@@ -16,19 +21,38 @@ def translate_kml_document(request, document):
     return document.replace(u"See the original resource", translation)
 
 
+fixes = [
+    (re.compile(r'type="xsd:([a-z]+)"'), 'type="\g<1>"')
+]
+
+
+def fix_common_kml_problems(content):
+    for expression, substitute in fixes:
+        content = expression.sub(substitute, content)
+
+    return content
+
+
 def fetch_kml_document(url):
 
     candidates = (url, url + '/@@kml-document')
 
     for url in candidates:
-        response = requests.get(url)
+        try:
+            response = requests.get(url)
+        except requests.exceptions.RequestException:
+            continue
 
         if response.status_code != 200:
             continue
 
         try:
-            fastkml.kml.KML().from_string(response.content)
+            # fix common problems with kml
+            fastkml.kml.KML().from_string(
+                fix_common_kml_problems(response.content)
+            )
         except (lxml.etree.XMLSyntaxError, TypeError):
+            log.exception("Error parsing KML")
             continue
         else:
             return response.content.decode('utf-8')
